var test = require('tape')
var fs = require('fs')
var path = require('path')
var isES5 = require('is-es5')
var f = require('../')
var src = fs.readFileSync(path.join(__dirname, '../index.js'), 'utf-8')

test('it works', function (t) {
  t.equal(f(999), '0:00', 'anything under a second is 0:00')
  t.equal(f(1000), '0:01', 'check 1000 milliseconds is a second')
  t.equal(f(1000 * 2 - 1), '0:01', 'rounds 1999 down to 0:01')
  t.equal(f(1000 * 60), '1:00', 'check 60 seconds is a minute')
  t.equal(f(1000 * 60 - 1), '0:59', 'check 59 seconds looks ok')
  t.equal(f(1000 * 60 * 60), '1:00:00', 'check 60 minutes is an hour')
  t.equal(f(1000 * 60 * 60 - 1), '59:59', 'check 59 minutes looks ok')
  t.equal(f(1000 * 60 * 60 * 24), '1:00:00:00', 'check 24 hours is a day')
  t.equal(f(1000 * 60 * 60 * 24 - 1), '23:59:59', 'check 23 hours looks okay')
  t.equal(f(1000 * 60 * 60 * 24 * 365), '365:00:00:00', 'check 365 days is too long to care')
  t.end()
})

test('it works with negative durations', function (t) {
  t.equal(f(-999), '0:00', 'anything under a second is 0:00')
  t.equal(f(-1000), '-0:01', 'check -1000 milliseconds is a second')
  t.equal(f(-1000 * 2 + 1), '-0:01', 'rounds -1999 up to -0:01')
  t.equal(f(-1000 * 60), '-1:00', 'check -60 seconds is a minute')
  t.equal(f(-1000 * 60 + 1), '-0:59', 'check -59 seconds looks ok')
  t.equal(f(-1000 * 60 * 60), '-1:00:00', 'check -60 minutes is an hour')
  t.equal(f(-1000 * 60 * 60 + 1), '-59:59', 'check -59 minutes looks ok')
  t.equal(f(-1000 * 60 * 60 * 24), '-1:00:00:00', 'check -24 hours is a day')
  t.equal(f(-1000 * 60 * 60 * 24 + 1), '-23:59:59', 'check -23 hours looks okay')
  t.equal(f(-1000 * 60 * 60 * 24 * 365), '-365:00:00:00', 'check -365 days is too long to care')
  t.end()
})

test('it works with leading zeros', function (t) {
  t.equal(f(999, { leading: true }), '00:00', 'anything under a second is 00:00')
  t.equal(f(1000, { leading: true }), '00:01', 'check 1000 milliseconds is a second')
  t.equal(f(1000 * 2 - 1, { leading: true }), '00:01', 'rounds 1999 down to 00:01')
  t.equal(f(1000 * 60, { leading: true }), '01:00', 'check 60 seconds is a minute')
  t.equal(f(1000 * 60 - 1, { leading: true }), '00:59', 'check 59 seconds looks ok')
  t.equal(f(1000 * 60 * 60, { leading: true }), '01:00:00', 'check 60 minutes is an hour')
  t.equal(f(1000 * 60 * 60 - 1, { leading: true }), '59:59', 'check 59 minutes looks ok')
  t.equal(f(1000 * 60 * 60 * 24, { leading: true }), '1:00:00:00', 'check 24 hours is a day')
  t.equal(f(1000 * 60 * 60 * 24 - 1, { leading: true }), '23:59:59', 'check 23 hours looks okay')
  t.equal(f(1000 * 60 * 60 * 24 * 365, { leading: true }), '365:00:00:00', 'check 365 days is too long to care')
  t.end()
})

test('is ES5', function (t) {
  t.equal(isES5(src), true, 'is ES5')
  t.end()
})
